<?php

$lan = array(

'Mass unconfirm email addresses' => 'Mass unconfirm email addresses',
'Paste the emails to mark unconfirmed in this box, and click continue' => 'Paste the emails to mark unconfirmed in this box, and click continue',
'All done, %d emails processed, %d emails marked unconfirmed<br/>' => 'All done, %d emails processed, %d emails marked unconfirmed<br/>',
'All done, %d emails processed, %d emails marked unconfirmed, %d emails blacklisted<br/>' => 'All done, %d emails processed, %d emails marked unconfirmed, %d emails blacklisted<br/>',
);
?>